"use strict";

var _finder = _interopRequireDefault(require("./finder"));
var _fs = _interopRequireDefault(require("fs"));
var _yargs = _interopRequireDefault(require("yargs"));
var _fastFileLogger = _interopRequireDefault(require("fast-file-logger"));
var _params$i;
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
var toGeofeed = function toGeofeed(geofeedsObjects) {
  return geofeedsObjects.join("\n");
};
var logger = new _fastFileLogger["default"]({
  logRotatePattern: "YYYY-MM-DD",
  filename: 'error-%DATE%.log',
  symLink: false,
  directory: "./logs",
  maxRetainedFiles: 100,
  maxFileSizeMB: 100,
  compressOnRotation: false,
  label: "geofeed-finder",
  useUTC: true,
  format: function format(_ref) {
    var data = _ref.data,
      timestamp = _ref.timestamp;
    return "".concat(timestamp, " ").concat(data);
  }
});
var params = _yargs["default"].usage('Usage: $0 <command> [options]').command('$0', 'Run Geofeed finder (default)', function () {
  _yargs["default"].alias('v', 'version').nargs('v', 0).describe('v', 'Show version number').alias('a', 'af').nargs('a', 1)["default"]('a', '4,6').describe('a', 'Address family').alias('o', 'output').nargs('o', 1)["default"]('o', 'result.csv').describe('o', 'Output file').alias('t', 'test').nargs('t', 1).describe('t', 'Test specific inetnum using RDAP').alias('c', 'cache-whois').nargs('c', 1)["default"]('c', 3).describe('c', "Number of days whois cache validity").alias('g', 'cache-geofeed').nargs('g', 1)["default"]('g', 3).describe('g', "Number of days geofeed file cache validity").alias('l', 'cache-location').nargs('l', 1)["default"]('l', ".cache/").describe('l', "Cache directory location").alias('s', 'silent').nargs('s', 0).describe('s', "Silent mode, don't print errors").alias('u', 'keep-invalid-subdivisions').nargs('u', 0).describe('u', "Keep invalid subdivisions (accept invalid ISO regions/subdivisions)").alias('r', 'remove-invalid-subdivisions').nargs('r', 0).describe('r', "Remove invalid subdivisions but keep the rest of the geofeed if valid").alias('b', 'arin-bulk').nargs('b', 0).describe('b', 'Use bulk whois data for ARIN: https://www.arin.net/reference/research/bulkwhois/').alias('p', 'arin-skip-suballocations').nargs('p', 0).describe('p', 'Do not fetch ARIN\'s sub allocations. You will save considerable time but have a potentially partial output.').alias('q', 'detect-suballocations-locally').nargs('q', 0).describe('q', 'Detect ARIN\'s sub allocations locally instead of downloading a dump file.').alias('z', 'include-zip').nargs('z', 0).describe('z', 'Zip codes are deprecated in geofeed and by default are excluded from the output.').alias('k', 'keep-non-iso').nargs('k', 0).describe('k', 'Keep entries with invalid ISO codes').alias('d', 'download-timeout').nargs('d', 1).describe('d', "Interrupt downloading a geofeed file after seconds").alias('i', 'include').nargs('i', 1)["default"]('i', 'ripe,apnic,lacnic,afrinic,arin').describe('i', 'Include RIRs (comma-separated list)');
}).help('h').alias('h', 'help').epilog('Copyright (c) 2020, Massimo Candela').argv;
var options = {
  logger: logger,
  cacheDir: params.l || ".cache/",
  whoisCacheDays: parseInt(params.c),
  daysWhoisSuballocationsCache: 15,
  // Cannot be less than 7
  compileSuballocationLocally: !!params.q,
  skipSuballocations: !!params.p,
  geofeedCacheDays: parseInt(params.g),
  arinBulk: params.b,
  af: params.a.toString().split(",").map(function (i) {
    return parseInt(i);
  }),
  includeZip: !!params.z,
  silent: !!params.s,
  keepNonIso: !!params.k,
  keepInvalidSubdivisions: !!params.u,
  removeInvalidSubdivisions: !!params.r,
  include: ((_params$i = params.i) !== null && _params$i !== void 0 ? _params$i : "ripe,apnic,lacnic,afrinic,arin").split(","),
  output: params.o || "result.csv",
  test: params.t || null,
  downloadTimeout: params.d || 10 // 0 is not a valid value
};
new _finder["default"](options).getGeofeeds().then(function (data) {
  if (!!options.test) {
    if (/<a|<div|<span|<style|<link/gi.test(data)) {
      console.log("Error: is not CSV but HTML, stop with this nonsense!");
    } else {
      console.log(toGeofeed(data));
    }
  } else {
    _fs["default"].writeFileSync(options.output, "");
    var out = _fs["default"].createWriteStream(options.output, {
      flags: 'a'
    });
    var _iterator = _createForOfIteratorHelper(data !== null && data !== void 0 ? data : []),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var line = _step.value;
        out.write(line + "\n");
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    out.end();
    console.log("Done! See ".concat(options.output));
  }
})["catch"](function (error) {
  logger.log(error.message);
});